{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#bgzip-vcf.cwl",
            "label": "bgzip file",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/tabix:0.2.6--ha92aebf_0",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "bgzip",
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip-vcf.cwl/bgzip file/vcf"
                }
            ],
            "stdout": "$(inputs.vcf.basename).gz",
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip-vcf.cwl/bgzip file/bgzipped_vcf",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename).gz"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/snpeff:4.3.1t--3",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "snpEff"
            ],
            "arguments": [
                "-Xmx4g",
                "-v",
                "-c",
                "$(inputs.dbdir.path)/snpEff.config",
                "$(inputs.dbname)",
                "$(inputs.vcf)"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#snpeff-annotate.cwl/dbdir"
                },
                {
                    "type": "string",
                    "default": "RAP_MSU_on_IRGSP-1.0",
                    "id": "#snpeff-annotate.cwl/dbname"
                },
                {
                    "type": "string",
                    "default": "snpeff.vcf",
                    "id": "#snpeff-annotate.cwl/out_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#snpeff-annotate.cwl/outprefix"
                },
                {
                    "type": "File",
                    "id": "#snpeff-annotate.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "snpEff_genes.txt",
                        "outputEval": "${ if(inputs.outprefix === null){ return self; } else { self[0].basename=\"snpEff_genes_\" + inputs.outprefix + \".txt\"; return self; } }"
                    },
                    "id": "#snpeff-annotate.cwl/genes"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "snpEff_summary.html",
                        "outputEval": "${ if(inputs.outprefix === null){ return self; } else { self[0].basename=\"snpEff_summary_\" + inputs.outprefix + \".html\"; return self; } }"
                    },
                    "id": "#snpeff-annotate.cwl/summary"
                },
                {
                    "$import": "#snpeff-annotate.cwl/vcf"
                }
            ],
            "stdout": "$(inputs.out_vcf)",
            "id": "#snpeff-annotate.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/snpeff:4.3.1t--3",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "sh"
            ],
            "arguments": [
                "$(inputs.script)",
                "$(inputs.genome)",
                "$(inputs.gtf)",
                "$(inputs.protein)",
                "$(inputs.dbname)",
                "$(inputs.dbdir)"
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "snpeff_db",
                    "id": "#snpeff-build.cwl/dbdir"
                },
                {
                    "type": "string",
                    "default": "RAP_MSU_on_IRGSP-1.0",
                    "id": "#snpeff-build.cwl/dbname"
                },
                {
                    "type": "File",
                    "id": "#snpeff-build.cwl/genome"
                },
                {
                    "type": "File",
                    "id": "#snpeff-build.cwl/gtf"
                },
                {
                    "type": "File",
                    "id": "#snpeff-build.cwl/protein"
                },
                {
                    "type": "File",
                    "default": {
                        "class": "File",
                        "location": "https://raw.githubusercontent.com/nigyta/rice_reseq/356c47bb87dbcd9a9cb565f147b0dad298dea6cb/tools/build_snpEff_db.sh"
                    },
                    "id": "#snpeff-build.cwl/script"
                }
            ],
            "outputs": [
                {
                    "$import": "#snpeff-build.cwl/dbdir"
                }
            ],
            "id": "#snpeff-build.cwl"
        },
        {
            "class": "CommandLineTool",
            "id": "#tabix-vcf.cwl",
            "label": "tabix-vcf",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/tabix:0.2.6--ha92aebf_0",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.vcf)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "tabix",
                "-p",
                "vcf"
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input VCF.gz file",
                    "id": "#tabix-vcf.cwl/tabix-vcf/vcf"
                }
            ],
            "arguments": [
                "$(inputs.vcf)"
            ],
            "outputs": [
                {
                    "id": "#tabix-vcf.cwl/tabix-vcf/tbi",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename).tbi"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#util-bindVcfIndex.cwl",
            "label": "Bind VCF.gz and tbi file",
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "$(inputs.vcf)"
                        },
                        {
                            "entry": "$(inputs.tbi)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": "true",
            "inputs": [
                {
                    "type": "File",
                    "id": "#util-bindVcfIndex.cwl/Bind VCF.gz and tbi file/tbi"
                },
                {
                    "type": "File",
                    "id": "#util-bindVcfIndex.cwl/Bind VCF.gz and tbi file/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#util-bindVcfIndex.cwl/Bind VCF.gz and tbi file/vcfgz_with_tbi"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "snpeff_db",
                    "id": "#main/dbdir"
                },
                {
                    "type": "string",
                    "default": "RAP_MSU_on_IRGSP-1.0",
                    "id": "#main/dbname"
                },
                {
                    "type": "File",
                    "id": "#main/genome"
                },
                {
                    "type": "File",
                    "id": "#main/gtf"
                },
                {
                    "type": "string",
                    "id": "#main/outprefix"
                },
                {
                    "type": "File",
                    "id": "#main/protein"
                },
                {
                    "type": "File",
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip-vcf.cwl",
                    "in": [
                        {
                            "source": "#main/snpeff_annotate/vcf",
                            "id": "#main/bgzip_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/bgzip_vcf/bgzipped_vcf"
                    ],
                    "id": "#main/bgzip_vcf"
                },
                {
                    "run": "#util-bindVcfIndex.cwl",
                    "in": [
                        {
                            "source": "#main/tabix_vcf/tbi",
                            "id": "#main/bind_vcf_index/tbi"
                        },
                        {
                            "source": "#main/bgzip_vcf/bgzipped_vcf",
                            "id": "#main/bind_vcf_index/vcf"
                        }
                    ],
                    "out": [
                        "#main/bind_vcf_index/vcfgz_with_tbi"
                    ],
                    "id": "#main/bind_vcf_index"
                },
                {
                    "run": "#snpeff-annotate.cwl",
                    "in": [
                        {
                            "source": "#main/snpeff_build/dbdir",
                            "id": "#main/snpeff_annotate/dbdir"
                        },
                        {
                            "source": "#main/dbname",
                            "id": "#main/snpeff_annotate/dbname"
                        },
                        {
                            "source": "#main/outprefix",
                            "valueFrom": "variants_$(self).snpEff.vcf",
                            "id": "#main/snpeff_annotate/out_vcf"
                        },
                        {
                            "source": "#main/outprefix",
                            "id": "#main/snpeff_annotate/outprefix"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/snpeff_annotate/vcf"
                        }
                    ],
                    "out": [
                        "#main/snpeff_annotate/vcf",
                        "#main/snpeff_annotate/genes",
                        "#main/snpeff_annotate/summary"
                    ],
                    "id": "#main/snpeff_annotate"
                },
                {
                    "run": "#snpeff-build.cwl",
                    "in": [
                        {
                            "source": "#main/dbdir",
                            "id": "#main/snpeff_build/dbdir"
                        },
                        {
                            "source": "#main/dbname",
                            "id": "#main/snpeff_build/dbname"
                        },
                        {
                            "source": "#main/genome",
                            "id": "#main/snpeff_build/genome"
                        },
                        {
                            "source": "#main/gtf",
                            "id": "#main/snpeff_build/gtf"
                        },
                        {
                            "source": "#main/protein",
                            "id": "#main/snpeff_build/protein"
                        }
                    ],
                    "out": [
                        "#main/snpeff_build/dbdir"
                    ],
                    "id": "#main/snpeff_build"
                },
                {
                    "run": "#tabix-vcf.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip_vcf/bgzipped_vcf",
                            "id": "#main/tabix_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/tabix_vcf/tbi"
                    ],
                    "id": "#main/tabix_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/snpeff_annotate/genes",
                    "id": "#main/snpeff_genes"
                },
                {
                    "type": "File",
                    "outputSource": "#main/snpeff_annotate/summary",
                    "id": "#main/snpeff_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bind_vcf_index/vcfgz_with_tbi",
                    "id": "#main/snpeff_vcf_with_tbi"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
